OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan inte skriva till \"config\" katalogen!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Detta kan vanligtvis åtgärdas genom att ge skrivrättigheter till config-katalogen",
    "See %s" : "Se %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den.",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Detta fixas vanligtvis genom att ge webbservern skrivrättigheter till konfigureringsmappen. Se %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerna i appen %1$s ersattes inte korrekt. Kontrollera att det är en version som är kompatibel med servern.",
    "Sample configuration detected" : "Exempel-konfiguration detekterad",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Vänligen läs dokumentationen innan du utför ändringar på config.php",
    "%1$s and %2$s" : "%1$s och %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s och %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s och %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s och %5$s",
    "Education Edition" : "Utbildningspaket",
    "Enterprise bundle" : "Företagspaketet",
    "Groupware bundle" : "Gruppvarupaket",
    "Social sharing bundle" : "Kommunikationspaket",
    "PHP %s or higher is required." : "PHP %s eller högre krävs.",
    "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
    "%sbit or higher PHP required." : "%sbit eller nyare PHP-version krävs.",
    "Following databases are supported: %s" : "Följande databastyper stöds: %s",
    "The command line tool %s could not be found" : "Kommandoradsverktyget %s hittades inte.",
    "The library %s is not available." : "Biblioteket %s är inte tillgängligt.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Bibliotek %1$s med en högre version än %2$s krävs - tillgänglig version %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Bibliotek %1$s med en lägre version än %2$s krävs - tillgänglig version %3$s.",
    "Following platforms are supported: %s" : "Följande plattformar stöds: %s",
    "Server version %s or higher is required." : "Serverversion %s eller nyare krävs.",
    "Server version %s or lower is required." : "Serverversion %s eller äldre krävs.",
    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
    "Wiping of device %s has started" : "Rensning av enhet %s har startat",
    "Wiping of device »%s« has started" : "Rensning av enhet »%s« har startat",
    "»%s« started remote wipe" : "»%s« startade fjärrensning",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enhet eller applikation »%s« har startat fjärrensning. Du kommer att få ett nytt mail när processen är klar",
    "Wiping of device %s has finished" : "Rensning av enhet %s har slutförts",
    "Wiping of device »%s« has finished" : "Rensning av enhet »%s« har slutförts",
    "»%s« finished remote wipe" : "»%s« slutförde fjärrensning",
    "Device or application »%s« has finished the remote wipe process." : "Enhet eller applikation »%s« har slutfört fjärrensning.",
    "Remote wipe started" : "Fjärrensning startad",
    "A remote wipe was started on device %s" : "Fjärrensning startades på enhet %s",
    "Remote wipe finished" : "Fjärrensning klar",
    "The remote wipe on %s has finished" : "Fjärrensning av enhet %s har slutörts",
    "Authentication" : "Autentisering",
    "Unknown filetype" : "Okänd filtyp",
    "Invalid image" : "Ogiltig bild",
    "Avatar image is not square" : "Profilbilden är inte fyrkantig",
    "today" : "idag",
    "tomorrow" : "imorgon",
    "yesterday" : "igår",
    "_in %n day_::_in %n days_" : ["om %n dag","om %n dagar"],
    "_%n day ago_::_%n days ago_" : ["%n dag sedan","%n dagar sedan"],
    "next month" : "nästa månad",
    "last month" : "förra månaden",
    "_in %n month_::_in %n months_" : ["om %n månad","om %n månader"],
    "_%n month ago_::_%n months ago_" : ["%n månad sedan","%n månader sedan"],
    "next year" : "nästa år",
    "last year" : "förra året",
    "_in %n year_::_in %n years_" : ["om %n år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år sedan","%n år sedan"],
    "_in %n hour_::_in %n hours_" : ["om %n timme","om %n timmar"],
    "_%n hour ago_::_%n hours ago_" : ["%n timme sedan","%n timmar sedan"],
    "_in %n minute_::_in %n minutes_" : ["om %n minut","om %n minuter"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut sedan","%n minuter sedan"],
    "in a few seconds" : "om några sekunder",
    "seconds ago" : "sekunder sedan",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finns inte längre. Vänligen aktivera det i dina appinställningar eller kontakta din administratör.",
    "File name is a reserved word" : "Filnamnet är ett reserverat ord",
    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
    "File name is too long" : "Filnamnet är för långt",
    "Dot files are not allowed" : "Dot-filer är inte tillåtna",
    "Empty filename is not allowed" : "Tomma filnamn är inte tillåtna",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan inte installeras eftersom appinfo-filen inte kan läsas.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
    "__language_name__" : "Svenska",
    "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt skickat e-postmeddelande, svara inte på detta meddelande.",
    "Help" : "Hjälp",
    "Apps" : "Appar",
    "Settings" : "Inställningar",
    "Log out" : "Logga ut",
    "Users" : "Användare",
    "Unknown user" : "Okänd användare",
    "Overview" : "Översikt",
    "Basic settings" : "Generella inställningar",
    "Sharing" : "Delning",
    "Security" : "Säkerhet",
    "Groupware" : "Grupprogram",
    "Additional settings" : "Övriga inställningar",
    "Personal info" : "Personlig information",
    "Mobile & desktop" : "Mobil & skrivbord",
    "%s enter the database username and name." : "%s ange användarnamn och namn för databasen.",
    "%s enter the database username." : "%s ange databasanvändare.",
    "%s enter the database name." : "%s ange databasnamn",
    "%s you may not use dots in the database name" : "%s du får inte använda punkter i databasnamnet",
    "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
    "You need to enter details of an existing account." : "Du måste ange inloggningsuppgifter av ett aktuellt konto.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Vänligen ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
    "Set an admin username." : "Ange ett användarnamn för administratören.",
    "Set an admin password." : "Ange ett administratörslösenord.",
    "Can't create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
    "Invalid Federated Cloud ID" : "Ogiltigt federerat moln-ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delningsgränssnittet %s hittades inte",
    "Sharing backend for %s not found" : "Delningsgränssnittet för %s hittades inte",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delade »%2$s« med dig och vill lägga till:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delade »%2$s« med dig och vill lägga till",
    "»%s« added a note to a file shared with you" : "»%s« la till en kommentar till en fil delad med dig",
    "Open »%s«" : "Öppna »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du har inte rätt att dela %s",
    "Can’t increase permissions of %s" : "Kan inte öka rättigheterna för %s",
    "Files can’t be shared with delete permissions" : "Filer kan inte delas med borttagningsrättigheter",
    "Files can’t be shared with create permissions" : "Filer kan inte delas med rättigheter att skapa",
    "Expiration date is in the past" : "Utgångsdatum är i det förflutna",
    "Can’t set expiration date more than %s days in the future" : "Kan inte sätta utgångsdatum mer än %s dagar framåt",
    "%1$s shared »%2$s« with you" : "%1$s delade »%2$s« med dig",
    "%1$s shared »%2$s« with you." : "%1$s delade »%2$s« med dig.",
    "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
    "The requested share does not exist anymore" : "Den begärda delningen finns inte mer",
    "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
    "Sunday" : "Söndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sun." : "Sön.",
    "Mon." : "Mån.",
    "Tue." : "Tis.",
    "Wed." : "Ons.",
    "Thu." : "Tors.",
    "Fri." : "Fre.",
    "Sat." : "Lör.",
    "Su" : "Sö",
    "Mo" : "Må",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lö",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Mars",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augusti",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Endast följande tecken är tillåtna i användarnamnet: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
    "A valid password must be provided" : "Ett giltigt lösenord måste anges",
    "The username is already being used" : "Användarnamnet används redan",
    "Could not create user" : "Kunde inte skapa användare",
    "User disabled" : "Användare inaktiverad",
    "Login canceled by app" : "Inloggningen avbruten av appen",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
    "a safe home for all your data" : "ett säkert hem för alla dina data",
    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, vänligen försök igen senare",
    "Can't read file" : "Kan inte läsa filen",
    "Application is not enabled" : "Applikationen är inte aktiverad",
    "Authentication error" : "Fel vid autentisering",
    "Token expired. Please reload page." : "Token har löpt ut. Vänligen uppdatera sidan.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
    "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
    "Cannot write into \"apps\" directory" : "Kan inte skriva till \"apps\" katalogen!",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Detta kan vanligtvis lösas genom att ge webbservern skrivåtkomst till mappen för appar eller genom att inaktivera appbutiken i konfigurationsfilen. Se %s",
    "Cannot create \"data\" directory" : "Kan inte skapa \"datamapp\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Detta kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Rättigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
    "Setting locale to %s failed" : "Sätta locale till %s misslyckades",
    "Please install one of these locales on your system and restart your webserver." : "Vänligen Installera en av dessa språk på ditt system och starta om webbservern.",
    "Please ask your server administrator to install the module." : "Vänligen be serveradministratören att installera modulen.",
    "PHP module %s not installed." : "PHP-modulen %s är inte installerad.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload är satt till \"%s\" istället för det förväntade värdet \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "För att åtgärda detta problem sätt värdet  <code> mbstring.func_overload till </ code> <code> 0 </ code> i din php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 är det minsta som krävs. För närvarande är %s installerat.",
    "To fix this issue update your libxml2 version and restart your web server." : "För att åtgärda detta problem uppdatera libxml2 versionen och starta om din webbserver.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställt för att tömma \"inline doc blocks\". Detta kommer att göra flera kärnprogram otillgängliga.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
    "Please ask your server administrator to restart the web server." : "Vänligen be din serveradministratör att starta om webbservern.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
    "Please upgrade your database version" : "Vänligen uppgradera din databasversion",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
    "Your data directory is readable by other users" : "Din datamapp är läsbar av andra användare",
    "Your data directory must be an absolute path" : "Du måste specificera en korrekt sökväg till datamappen",
    "Check the value of \"datadirectory\" in your configuration" : "Kontrollera värdet av \"datakatalog\" i din konfiguration",
    "Your data directory is invalid" : "Din datamapp är ogiltig",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för dina data.",
    "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds inte eller är inte implementerad.",
    "Authentication failed, wrong token or provider ID given" : "Autentisering misslyckades, felaktig token eller leverantörs-ID",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametrar saknas för att slutföra förfrågan. Saknade parametrar: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" används redan av moln - federationsleverantör \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Moln - federationsleverantör med ID: \"%s\" finns inte.",
    "Could not obtain lock type %d on \"%s\"." : "Kunde inte hämta låstyp %d på \"%s\".",
    "Storage unauthorized. %s" : "Lagring obehörig. %s",
    "Storage incomplete configuration. %s" : "Lagringsutrymme felaktigt inställt. %s",
    "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
    "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
    "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
    "Create" : "Skapa",
    "Change" : "Ändra",
    "Delete" : "Radera",
    "Share" : "Dela",
    "Unlimited" : "Obegränsad",
    "Verifying" : "Verifierar",
    "Verifying …" : "Verifierar ...",
    "Verify" : "Verifiera",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Misslyckades dela ut %s då backend inte tillåter delningar från typ %i",
    "Sharing %s failed, because the file does not exist" : "Delning av %s misslyckades på grund av att filen inte existerar",
    "Sharing %s failed, because you can not share with yourself" : "Delning %s misslyckades därför att du inte kan dela med dig själv.",
    "Sharing %1$s failed, because the user %2$s does not exist" : "Delning %1$s misslyckades för att användaren %2$s inte finns",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Delning %1$s misslyckades för att användaren %2$s inte är medlem i några grupper som %3$s är medlem i",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Delning %1$s misslyckades, är redan delad med %2$s",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Delning %1$s misslyckades, är redan delad med användare %2$s",
    "Sharing %1$s failed, because the group %2$s does not exist" : "Delning %1$s misslyckades för att gruppen %2$s finns inte",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Delning %1$s misslyckades för att %2$s är inte medlem i gruppen %3$s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du måste ange ett lösenord för att skapa en offentlig länk, endast skyddade länkar är tillåtna",
    "Sharing %s failed, because sharing with links is not allowed" : "Delning %s misslyckades därför att delning av länkar inte är tillåtet",
    "Not allowed to create a federated share with the same user" : "Inte tillåtet att skapa en federerad delning med samma användare",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Delning %1$s misslyckades, kan inte hitta %2$s, servern är kanske inte åtkomlig för närvarande.",
    "Share type %1$s is not valid for %2$s" : "Delningstyp %1$s är inte giltig för %2$s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan inte sätta utgångsdatum. Utdelningar kan inte utgå senare än %s efter de har delats ut",
    "Cannot set expiration date. Expiration date is in the past" : "Kan inte sätta utgångsdatum. Utgångsdatumet är i det förflutna.",
    "Sharing failed, because the user %s is the original sharer" : "Delning misslyckades eftersom användaren %s redan är den som har delat detta.",
    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Delning %1$s misslyckades därför att rättigheterna överskrider de rättigheter som tilldelats %2$s",
    "Sharing %s failed, because resharing is not allowed" : "Delning %s misslyckades därför att vidaredelning inte är tillåten",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Delning %1$s misslyckades därför att delningsgränssnittet för %2$s inte kunde hitta sin källa",
    "Sharing %s failed, because the file could not be found in the file cache" : "Delning %s misslyckades därför att filen inte kunde hittas i filcachen"
},
"nplurals=2; plural=(n != 1);");
